---
layout: graph
title: Users Pack Hierarchy
---

<svg id="pack_users"></svg>
<script src="{{ site.baseurl }}/assets/js/extractors/pack_users.js"></script>

<script>
$(document).ready(function(){
  draw_pack_hierarchy('#pack_users');
})
</script>
